' . "\n" . '' . "\n" . '
' . "\n" . '
' . "\n" . '' . "\n" . ' '
);
- if ( ( $tmp['55a29bcf74bb2'] = call_user_func_array(array(Service::get('invalides.portraits.crud'), 'read'), array(array(
+ if ( ( $tmp['56b34aabbfaa7'] = call_user_func_array(array(Service::get('invalides.portraits.crud'), 'read'), array(array(
'actif' => 1
- )) ) ) && count($tmp['55a29bcf74bb2']) )
- foreach ( $tmp['55a29bcf74bb2'] as $k => $v ) {
+ )) ) ) && count($tmp['56b34aabbfaa7']) )
+ foreach ( $tmp['56b34aabbfaa7'] as $k => $v ) {
$data["portrait"] = $v;
$data["idx"] = $k;
$runtime->appendContent(
@@ -45,10 +45,10 @@ $runtime->cpush($runtime->alloc["cnt"]);
ExpressionTypeArrayAccess::runtime(ExpressionTypeArrayAccess::runtime($data, 'page'), 'introduction') .
'' . "\n" . ' ' . "\n" . '
' . "\n" . ' ' . "\n" . ' '
);
- if ( ( $tmp['55a29bcf74d6a'] = call_user_func_array(array(Service::get('invalides.portraits.crud'), 'read'), array(array(
+ if ( ( $tmp['56b34aabbffb1'] = call_user_func_array(array(Service::get('invalides.portraits.crud'), 'read'), array(array(
'actif' => 1
- )) ) ) && count($tmp['55a29bcf74d6a']) )
- foreach ( $tmp['55a29bcf74d6a'] as $k => $v ) {
+ )) ) ) && count($tmp['56b34aabbffb1']) )
+ foreach ( $tmp['56b34aabbffb1'] as $k => $v ) {
$data["portrait"] = $v;
$data["idx"] = $k;
$runtime->appendContent(
diff --git a/choupas/www/admin/app/providers/invalides/auto/Model.annexesContents.php b/choupas/www/admin/app/providers/invalides/auto/Model.annexesContents.php
index f8c6874..0c99213 100755
--- a/choupas/www/admin/app/providers/invalides/auto/Model.annexesContents.php
+++ b/choupas/www/admin/app/providers/invalides/auto/Model.annexesContents.php
@@ -152,11 +152,11 @@ return array(
'plural' => '',
),
'value' => array(
- 'minlength' => 0,
- 'maxlength' => 255,
+ 'min' => -4294967297,
+ 'max' => 4294967296,
'default' => null,
'null' => false,
- 'type' => 'string',
+ 'type' => 'integer',
),
),
'image2' => array(
@@ -184,11 +184,11 @@ return array(
'plural' => '',
),
'value' => array(
- 'minlength' => 0,
- 'maxlength' => 255,
+ 'min' => -4294967297,
+ 'max' => 4294967296,
'default' => null,
'null' => false,
- 'type' => 'string',
+ 'type' => 'integer',
),
),
'image3' => array(
@@ -216,11 +216,11 @@ return array(
'plural' => '',
),
'value' => array(
- 'minlength' => 0,
- 'maxlength' => 255,
+ 'min' => -4294967297,
+ 'max' => 4294967296,
'default' => null,
'null' => false,
- 'type' => 'string',
+ 'type' => 'integer',
),
),
'image4' => array(
@@ -248,11 +248,11 @@ return array(
'plural' => '',
),
'value' => array(
- 'minlength' => 0,
- 'maxlength' => 255,
+ 'min' => -4294967297,
+ 'max' => 4294967296,
'default' => null,
'null' => false,
- 'type' => 'string',
+ 'type' => 'integer',
),
),
'Imagecentree' => array(
@@ -264,11 +264,11 @@ return array(
'plural' => '',
),
'value' => array(
- 'minlength' => 0,
- 'maxlength' => 255,
+ 'min' => -4294967297,
+ 'max' => 4294967296,
'default' => null,
'null' => false,
- 'type' => 'string',
+ 'type' => 'integer',
),
),
'legendeimagecentree' => array(
@@ -280,11 +280,11 @@ return array(
'plural' => '',
),
'value' => array(
- 'minlength' => 0,
- 'maxlength' => 255,
+ 'min' => -4294967297,
+ 'max' => 4294967296,
'default' => null,
'null' => false,
- 'type' => 'string',
+ 'type' => 'integer',
),
),
'imagefull' => array(
@@ -296,11 +296,11 @@ return array(
'plural' => '',
),
'value' => array(
- 'minlength' => 0,
- 'maxlength' => 255,
+ 'min' => -4294967297,
+ 'max' => 4294967296,
'default' => null,
'null' => false,
- 'type' => 'string',
+ 'type' => 'integer',
),
),
'legendeimagefull' => array(
@@ -312,11 +312,11 @@ return array(
'plural' => '',
),
'value' => array(
- 'minlength' => 0,
- 'maxlength' => 255,
+ 'min' => -4294967297,
+ 'max' => 4294967296,
'default' => null,
'null' => false,
- 'type' => 'string',
+ 'type' => 'integer',
),
),
'Audio' => array(
@@ -344,11 +344,11 @@ return array(
'plural' => '',
),
'value' => array(
- 'minlength' => 0,
- 'maxlength' => 255,
+ 'min' => -4294967297,
+ 'max' => 4294967296,
'default' => null,
'null' => false,
- 'type' => 'string',
+ 'type' => 'integer',
),
),
),
diff --git a/choupas/www/admin/app/providers/invalides/auto/provider.php b/choupas/www/admin/app/providers/invalides/auto/provider.php
index 4fd58ab..b663eab 100755
--- a/choupas/www/admin/app/providers/invalides/auto/provider.php
+++ b/choupas/www/admin/app/providers/invalides/auto/provider.php
@@ -2,9 +2,9 @@
return array(
'type' => 'MySQLProvider',
- 'host' => '10.42.42.8',
- 'user' => 'choupas',
- 'password' => 'rTAu83FZu4E63MEe',
+ 'host' => 'localhost',
+ 'user' => 'root',
+ 'password' => '8MW8zgD8EUqZaE',
'dbname' => 'choupas',
'encoding' => 'utf-8',
'name' => 'invalides',
diff --git a/choupas/www/admin/app/providers/invalides/provider.php b/choupas/www/admin/app/providers/invalides/provider.php
index af236cb..1c9fbc1 100755
--- a/choupas/www/admin/app/providers/invalides/provider.php
+++ b/choupas/www/admin/app/providers/invalides/provider.php
@@ -2,9 +2,9 @@
return array(
'type' => 'MySQLProvider',
- 'host' => '10.42.42.8',
- 'user' => 'choupas',
- 'password' => 'rTAu83FZu4E63MEe',
+ 'host' => 'localhost',
+ 'user' => 'root',
+ 'password' => '8MW8zgD8EUqZaE',
'dbname' => 'choupas',
'encoding' => 'utf-8',
'name' => 'invalides',
diff --git a/choupas/www/admin/phpmy/CONTRIBUTING.md b/choupas/www/admin/phpmy/CONTRIBUTING.md
index ad567ef..e13da81 100644
--- a/choupas/www/admin/phpmy/CONTRIBUTING.md
+++ b/choupas/www/admin/phpmy/CONTRIBUTING.md
@@ -4,9 +4,18 @@ As an open source project, phpMyAdmin welcomes contributions of many forms.
## Bug reporting
-Please report [bugs on SourceForge.net][1].
+We appreciate your effort to improve phpMyAdmin by submitting a bug report. Before doing so, please check the following things:
-[1]: https://sourceforge.net/p/phpmyadmin/bugs/new/
+1. Check whether the bug you face **hasn't been already reported**. Duplicate reports takes us time, that we could be used to fix other bugs or make improvements.
+2. Specify the phpMyAdmin, server, PHP, MySQL and browser information that may be helpful to fix the problem, especially exact **version numbers**.
+3. If you got some error, please **describe what happened** and add error message. Reports like "I get error when I clicked on some link." are useless.
+4. Provide easy steps to reproduce and if possible include your table structure (``SHOW CREATE TABLE `tbl_name```); if your problem implies specific data, attach a small export file for sample rows.
+5. **Security problems** should not be reported here. See [our security page](https://www.phpmyadmin.net/security/).
+Thanks for your help!
+
+Please report [bugs on GitHub][1].
+
+[1]: https://github.com/phpmyadmin/phpmyadmin/issues/new
## Patches submission
@@ -22,4 +31,4 @@ tag, you are giving permission to license the patch as GPLv2-or-later. See
You can find more information on our website:
-http://www.phpmyadmin.net/home_page/improve.php
+https://www.phpmyadmin.net/contribute/
diff --git a/choupas/www/admin/phpmy/ChangeLog b/choupas/www/admin/phpmy/ChangeLog
index e15c82d..17f3e6a 100644
--- a/choupas/www/admin/phpmy/ChangeLog
+++ b/choupas/www/admin/phpmy/ChangeLog
@@ -1,6 +1,329 @@
phpMyAdmin - ChangeLog
======================
+4.5.4.1 (2016-01-29)
+- issue #11892 Error with PMA 4.4.15.3
+- issue #11896 Remove hard dependency on phpseclib
+
+4.5.4.0 (2016-01-28)
+- issue #11724 live data edit of big sets is not working
+- issue Table list not saved in db QBE bookmarked search
+- issue #11777 While 'changing a column', query fails with a syntax error after the 'CHARSET=' keyword
+- issue #11783 Avoid syntax error in javascript messages on invalid PHP setting for max_input_vars
+- issue #11784 Properly handle errors in upacking zip archive
+- issue #11785 Set PHP's internal encoding to UTF-8
+- issue #11786 Fixed Kanji encoding in some specific cases
+- issue #11787 Check whether iconv works before using it
+- issue #11788 Avoid conversion of MySQL error messages
+- issue #11792 Undefined index: parameters
+- issue #11802 Undefined index: field_name_orig
+- issue Undefined index: host
+- issue #11810 'Add to central columns' (per column button) does nothing
+- issue #11727 SQL duplicate entry error trying to INSERT in designer_settings table
+- issue #11798 Fix handling of databases with dot in a name
+- issue #11820 Fix hiding of page content behind menu
+- issue #11780 FROM clause not generated after loading search bookmark
+- issue #11826 Fix creating/editing VIEW with DEFINER containing special chars
+- issue #11828 Do not invoke FLUSH PRIVILEGES when server in --skip-grant-tables
+- issue #11804 Misleading message for configuration storage
+- issue #11772 Table pagination does nothing when session expired
+- issue #11840 Index comments not working properly
+- issue #11791 Better handle local storage errors
+- issue #11752 Improve detection of privileges for privilege adjusting
+- issue #11854 Undefined property: stdClass::$releases at version check when disabled in config
+- issue #11814 SQL comment and variable stripped from bookmark on save
+- issue Gracefully handle errors in regex based javascript search
+- issue [Security] Multiple full path disclosure vulnerabilities, see PMASA-2016-1
+- issue [Security] Unsafe generation of CSRF token, see PMASA-2016-2
+- issue [Security] Multiple XSS vulnerabilities, see PMASA-2016-3
+- issue [Security] Insecure password generation in JavaScript, see PMASA-2016-4
+- issue [Security] Unsafe comparison of CSRF token, see PMASA-2016-5
+- issue [Security] Multiple full path disclosure vulnerabilities, see PMASA-2016-6
+- issue [Security] XSS vulnerability in normalization page, see PMASA-2016-7
+- issue [Security] Full path disclosure vulnerability in SQL parser, see PMASA-2016-8
+- issue [Security] XSS vulnerability in SQL editor, see PMASA-2016-9
+
+4.5.3.1 (2015-12-25)
+- issue #11774 Undefined offset 2
+- issue [Security] Path disclosure, see PMASA-2015-6
+
+4.5.3.0 (2015-12-23)
+- issue #11744 Incomplete results of UNION ALL
+- issue #11742 MATCH AGAINST keywords not recognized
+- issue #11723 syntax verifier is not knowing "STRAIGHT_JOIN"
+- issue #11699 REPLACE() function confused with REPLACE statement
+- issue #11690 FLUSH word not recognized by parser
+- issue #11664 Online syntax verifier bug - "IF" on SELECT statement
+- issue #11665 Format breaks query with COUNT()
+- issue Undefinex index: SendErrorReports
+- issue Incorrect script name in include
+- issue #11685 Warning: Invalid argument supplied for foreach()
+- issue #11687 Delimiter missing while exporting multiple db routines
+- issue #11684 mysql_native_password with MariaDB bug
+- issue #11693 Flush privileges overusage - related to #11597
+- issue #11691 Query was empty on creating User in 4.5.2
+- issue #11695 PMA_getDataForDeleteUsers() warning
+- issue #11698 Cannot create user on Percona Server
+- issue Properly report error on connecting
+- issue #11706 Database export template not saving compression option
+- issue #11721 Fix single quote export for servers in ANSI_QUOTES mode
+- issue #11714 Avoid duplicite fetching of table information
+- issue #11724 Temporary fix for live data edit of big sets is not working
+- issue IE 8 compatibility in console
+- issue #11732 Exporting feature does not work with union table
+- issue #11728 CSV import skip row count after
+- issue #11679 Cannot export results of some queries
+- issue #11720 Message "An account already exists..." incorrectly displayed
+- issue #11758 Missing quoting of table in ALTER CONVERT query
+- issue #11752 PMA 4.5.2 breaks MySQL Master-Master Cluster
+- issue #11757 Export and preview show different SQL for character set
+- issue #11749 Fix possible undefined variables in table operations
+
+4.5.2.0 (2015-11-23)
+- issue #11589 Incorrect parameter in mysqli_fetch_fields()
+- issue #11592 Missing headers in zipped export
+- issue #11590 Parser: Array to string conversion
+- issue #11597 Huge binary log growth on 4.5.x
+- issue #11594 'only_db' config option bug when db names contain underscore and are grouped
+- issue #11607 Unable to change password from Login information tab
+- issue #11610 Undefined variable: res_rel
+- issue #11611 Warning while exporting schema to PDF
+- issue #11612 Undefined index: new_row_format
+- issue #11605 Changing hostname kills password
+- issue #11614 Undefined variable: db
+- issue #11627 CREATE TABLE/INSERT INTO executed twice (ctrl+enter)
+- issue #11630 Warning: mysqli_fetch_array() expects parameter 1 to be mysqli_result, boolean given
+- issue #11632 Exporting GIS visualization ignores start and row count
+- issue #11476 Errors instead of git info when PHP has no gzip support
+- issue #11633 CodeMirror tooltip shows below modal window
+- issue #11639 Bug with the MainBackground Color
+- issue Profiling checkbox is missing
+- issue #11642 Properly handle session expiry after POST requests
+- issue #11648 Notice in ./export.php#214 Undefined index: quick_or_custom
+- issue #11646 Unrecognized keywords
+- issue #11635 Sql not executed properly
+- issue #11631 Linter warnings when creating new user
+- issue #11626 wrong row count for query results
+- issue #11608 Analyzer doesn't recognize GRANT statements
+- issue #11602 Parser warnings (subqueries)
+- issue #11658 Collation column is empty in table Structure
+- issue #11661 Error changing table's column encoding
+
+4.5.1.0 (2015-10-23)
+- issue Invalid argument supplied for foreach()
+- issue array_key_exists() expects parameter 2 to be array
+- issue #11480 Notice Undefined index: drop_database
+- issue #11486 Server variable edition in ANSI_QUOTES sql_mode: losing current value
+- issue #11491 Propose table structure broken
+- issue #11464 phpMyAdmin suggests upgrading to newer version not usable on that system
+- issue #11495 'PMA_Microhistory' is undefined
+- issue #11496 Incorrect definition for getTablesWhenOpen()
+- issue #11500 Error when creating new user on MariaDB 10.0.21
+- issue #11505 Notice on htmlspecialchars()
+- issue Notice in Structure page of views
+- issue #11510 AUTO_INCREMENT always exported when IF NOT EXISTS is on
+- issue #11516 Some partitions are missing in copied table
+- issue #11521 Notice of undefined variable when performing SHOW CREATE
+- issue #11509 Error exporting sql query results with table alias
+- issue #11512 SQL editing window does not recognise 'OUTER' keyword in 'LEFT OUTER JOIN'
+- issue #11518 "NOT IN" clause not recognized (MySQL 5.6 and 5.7)
+- issue #11524 Yellow star does not change in database Structure after add/remove from favorites
+- issue #11531 Invalid SQL in table definition when exporting table
+- issue #11526 Foreign key to other database's tables fails
+- issue #11519 Bug while exporting results when a joined table field name is in SELECT query
+- issue #11522 Strange behavior on table rename
+- issue #11539 Rename table does not result in refresh in left panel
+- issue #11541 Missing arguments for PMA_Table::generateAlter()
+- issue #11544 Notices about undefined indexes on structure pages of information_schema tables
+- issue Change minimum PHP version for Composer
+- issue #11542 Import parser and backslash
+- issue #11546 "Visualize GIS data" seems to be broken
+- issue #11548 Confirm box on "Reset slave" option
+- issue Fix cookies clearing on version change
+- issue #11558 Cannot execute SQL with subquery
+- issue #11520 Incorrect syntax creating a user using mysql_native_password with MariaDB
+- issue #11561 Cannot use third party auth plugins
+
+4.5.0.2 (2015-09-25)
+- issue #11497 Incorrect indexes when exporting
+
+4.5.0.1 (2015-09-24)
+- issue #11492 AUTO_INCREMENT statements are partly missing from exports
+
+4.5.0.0 (2015-09-23)
++ rfe Pagination for GIS visualization
++ issue #6207 Usability improvements for console
++ issue #6310 Access to Add columns text-box and Go button when creating table
++ issue #6007 Add lock tables, disable keys options
++ issue #6306 Additional page locking
++ issue #6314 Support MySQL 5.7 syntax for password change
++ issue #6319 Display/edit index name
++ issue #6318 Toggle autocomplete of table and column names
++ issue #5633 Manage multiple variable in bookmarked query
++ issue #5642 Show edit/delete also when there is calculated column
++ issue #6313 Show databases as list instead of as dropdown when no database is selected
++ rfe Optional dark theme for the console
++ issue #5053 PDF schema sort options
++ issue #5543 Structure in PDF export
++ issue #6327 Have ZeroConf create phpmyadmin DB if possible
++ issue #5462 Warning before silent data conversion/truncation
++ issue #6338 Support a default page in designer
++ issue #6339 Allow copying mutiple rows
++ issue #6334 No SQL query for loading data
++ issue #6341 New data validation feature and datetime type
++ issue #6324 Importing and exporting pMA meta-data
++ issue #6330 Add grouping to stored procedures in the navigation tree
++ issue #6275 Support IPv6 browser transformation
++ rfe Option groups for 'With selected' dropdown in database structure page
++ issue #6347 Support CHECKSUM TABLE operation
++ issue #6088 Support for Paramaters with raw SQL
++ issue #5844 Show original size of truncated columns
++ issue #6114 Explain analyzer
++ issue #6186 Add "Drop partition" option to partition tools
++ issue #6354 Procedures window shift-click should select multiple rows
++ issue #6355 Designer: "Sticky" menu option
++ issue #6357 Directly show table comments in structure view
++ issue #6259 Page-related settings
++ issue #5356 Alter privileges when renaming or copying a database
+- issue #11256 Slowness due to large number of routines
+- issue #11258 GROUP_CONCAT shown as GROUPBY_CONCAT in CodeMirror autocomplete
++ issue #5946 Work with --skip-grant-tables
+- issue #11266 "Sort by key" drop-down value is lost
++ issue #6287 Browse: improve display of right-aligned data
+- issue #11265 Textarea rows settings ignored Features > Text fields
++ issue #6358 MIME types should be lower case
+- issue #11226 Drop table doesn't remove the table name from navigation bar
++ issue #6360 MySQL and MariaDB functions INET6_ATON and INET6_NTOA
+- bug Link to get real row counts of all the views in a db, at once
+- issue #11275 Drizzle version numbers
++ issue #5400 Rewrite print view using CSS; fixes print view failures on multi-query statements
++ issue #6362 Support spatial indexes in table create form
++ issue #6068 Use CTRL or ALT plus arrow keys for navigation in grid editor
++ rfe Remove support for Shift + Click on function name to apply to all rows in insert/edit page
++ issue #6326 Don't group tables in tree if the result has only one group
+- issue #11287 When hide table structure actions is false, action should be in a row
++ issue #5425 Batch changing the collation of each column in a table
+- issue #10918 QBE generates wrong query
++ issue #6292 Use plain English descriptors instead of script names for icon link destinations
++ issue #6239 Disable foreign key checks for some operations
+- issue #11296 "With selected" links doesn't work in table browse
+- issue #11166 Query builder: missing joint for the intermediary table
++ issue #6251 Integrate SQL debugging into console
+- issue #11061 Improve/restore non-unique index row editing
+- issue #11301 MySQL errors are not shown when DebugSQL is enabled
++ issue #5037 One file per table and one file per database export option
++ issue #5759 Designer settings should be part of saved state
++ issue #6257 Option to remove functions, procedures, etc., from navigation tree
++ issue #5388 Column privileges and update
++ issue #6231 Cant use external config file
++ issue #6252 CSV import: Allow "Columns escaped with" to be optional
++ issue #6262 Being able to use multiple servers at the same time when using cookie auth
++ issue #6301 select structure or data for each table when exporting
+- issue #11261 Autocomplete completes the original table name when joining multiple aliased tables
++ rfe Remove configuration storage data related to a user upon deleting the user
++ issue #6298 Improved processlist for mariadb
++ issue #6300 Warn about "Any user" potential problem
++ issue #6368 Hide/disable edit links for read-only variables
++ issue #6365 Human readable/writable URLs (html5 api)
++ rfe Support virtual columns in MySQL 5.7.5+
++ issue #6215 Support for virtual/persistent columns in MariaDB
+- issue #11314 Undefined
work upon upgrade to new version
+- issue #1817 Creating configuration storage tables fail in MySQL 5.7
+- issue #6118 Parser does not handle nested selects
+- issue #5437 Support SELECT ... FROM DUAL
+- issue #4962 Support UNION
+- issue #11322 Missing null checkbox when grid editing a null cell
++ Upgrade TCPDF to version 6.2.9
++ issue #6102 Add SHA256 security password support
+- issue #10250 Displayed git revision info is not set
++ Improved schema SVG export
+- issue #10726 Do not try to set port 80 for https requests
++ issue #11394 Export/import Designer view
++ Partition support in table Structure
++ issue #11414 Unclear export options / organization / hierarchy
+ Set minimum required PHP version to 5.5 (older versions are EOL)
+- issue #11407 ALTER TABLE failing on import when table exists
+- issue Do not export `sys` database when exporting server
+- issue #11436 CREATE DATABASE should be enabled by default on server exports
+- issue #11442 MySQL 5.7 and SHOW VARIABLES
+- issue #11445 MySQL 5.7 and Status page for an unprivileged user
+- issue #11448 Clarify doc about the MemoryLimit directive
+- issue #11489 Cannot copy a database under certain conditions
+
+4.4.15.1 (2015-10-23)
+- issue #11464 phpMyAdmin suggests upgrading to newer version not usable on that system
+- issue [security] Content spoofing on url.php
+
+4.4.15.0 (2015-09-20)
+- issue #11411 Undefined "replace" function on numeric scalar
+- issue #11421 Stored-proc / routine - broken parameter parsing
+- issue Missing name for configuration read_as_multibytes
+- issue #11431 Incorrect "No row selected" message
+- issue #11447 MySQL 5.5 and the language system variable
+- issue #11452 Semantics of export and import icons are mixed up
+- issue #11451 Designer-Bug in move.js on multiple server configuration
+- issue #11458 Invalid UTF-8 sequence in argument
+- issue #11457 Request URI too large
+- issue Invalid argument supplied for foreach()
+- issue #11461 Foreign key constraints for InnoDB tables with upper-case letters disabled
+- issue #11487 Warning when entering Query page
+
+4.4.14.1 (2015-09-08)
+- issue [security] reCaptcha bypass
+
+4.4.14.0 (2015-08-20)
+- issue #11367 Export after search, missing WHERE clause
+- issue #11380 Incomplete message after import
+- issue Incorrect scalar type declaration (reported under PHP 7)
+- issue #11389 ReCaptcha produces deprecated messages under PHP 7
+- issue #11387 phpseclib < 2.0 produces deprecated messages on PHP 7
+- issue #11404 "Switch to copied table" doesn't work
+- issue #11406 Missing quotes after calling "distinct values"
+- issue #11386 Cannot import database with long data in one column
+- issue #11410 SPATIAL index option is not clickable
+
+4.4.13.1 (2015-08-08)
+- issue #11368 SQL error when importing phpMyAdmin dump file
+
+4.4.13.0 (2015-08-07)
+- issue #1808 "Improve table structure" generates invalid SQL
+- issue Once checked "Show only active" checkbox is always checked
+- issue #1813 Delete rows using "Check All" is broken
+- issue Fix PHP 7 possible binding ambiguity
+- issue #11326 Exported schema includes all the tables of the database
+- issue #11339 Results not displayed if query ends in delimiter and comment
+- issue #11320 Live edit of data fields is not working always
+- issue Table list in navigation collapses when entering into a table in another page
+- issue #11364 JS error while trying to auto navigate to db structure page when db creation has failed
+
+4.4.12.0 (2015-07-20)
+- bug Saved chart image does not have a proper name or an extension
+- bug #4976 Timepicker CSS issues in Original theme
+- bug #4975 Move/Copy/Rename operations on Table/Db fail on Drizzle server
+- bug #4826 Two inline edit windows
+- bug #4979 Problem when import *.ods file
+- bug Add missing head tag
+- bug #4985 Column headers move when scrolling
+
+4.4.11.0 (2015-07-06)
+- bug Missing selected/entered values when editing active options in visual query builder
+- bug #4969 Autoload from prefs_storage not behaving properly
+- bug #4972 Incorrect length computed for binary data
+- bug Remove character set from create_tables_drizzle.sql
+- bug #4973 Users overview needs clarification
+- bug #4974 Creating a database from console doesn't update navigation panel
+- bug #4844 FAQ 1.17 needs an update
+
+4.4.10.0 (2015-06-17)
+- bug #4950 Issues in database selection for replication
+- bug #4951 Trying to save chart as image crashes the browser
+- bug #4953 cant drag sql.gz file onto import input
+- bug #4960 Table creation results in GET request with missing server parameter that invalidates the session
+- bug #4961 Javascript error when Designer is opened
+- bug #4962 Insert by foreign key scrolls page to top
+- bug #4955 Clicking on the navi logo does not always work
+- bug External URL for $cfg['NavigationLogoLink'] causes JavaScript error when clicked
+
4.4.9.0 (2015-06-04)
- bug #4920 relation view doesn't list fields of table in other database
- bug #4905 Sorting by an alias
@@ -79,8 +402,8 @@ phpMyAdmin - ChangeLog
4.4.3.0 (2015-04-20)
- bug #4851 PHP errors in login dialogue
-- bug #4845 White screen (Cloudflare)
- bug #4207 json_encode error due to strftime returning non utf8 chars in Windows 8.1 Chinese version
+- bug #4845 White screen (Cloudflare)
- bug #4794 Server error viewing table content
- bug Fix issues related to number of decimal places in time
- bug #4853 Relation view between 1600 and 1780 px
@@ -182,7 +505,7 @@ phpMyAdmin - ChangeLog
+ rfe Change tracking activation status from db level tracking page
+ rfe #1207 Export users associated with a specific schema/database
+ rfe #1575 "Disable database expansion" : unclear directive name and
-explanation
+explanation
+ rfe #1607 Tool tip for lock icon when making changes to a page
+ rfe #1327 Hide 'Add user' link if user does not have privileges
+ rfe #501 Support for SSL GRANT option
@@ -219,10 +542,7 @@ explanation
4.3.11.1 (2015-03-04)
- bug [security] Risk of BREACH attack, see PMASA-2015-1
-4.3.11.1 (not yet released)
-- bug [security] Risk of BREACH attack, see PMASA-2015-1
-
-4.3.11.0 (not yet released)
+4.3.11.0 (2015-03-02)
- bug #4774 SQL links are completely wrong
- bug #4768 MariaDB: version mismatch
- bug #4777 Some images are missing in Designer for original theme
@@ -273,7 +593,7 @@ explanation
- bug #4717 Database navigation menu broken when resolution/screen is changing
- bug #4727 Collation column missing in database list when DisableIS is true
- bug Undefined index central_columnswork
-- bug Undefined index favorite_tables
+- bug Undefined index favorite_tables
4.3.7.0 (2015-01-15)
- bug #4694 js error on marking table as favorite in Safari (in private mode)
diff --git a/choupas/www/admin/phpmy/LICENSE b/choupas/www/admin/phpmy/LICENSE
index 3912109..d159169 100644
--- a/choupas/www/admin/phpmy/LICENSE
+++ b/choupas/www/admin/phpmy/LICENSE
@@ -1,12 +1,12 @@
- GNU GENERAL PUBLIC LICENSE
- Version 2, June 1991
+ GNU GENERAL PUBLIC LICENSE
+ Version 2, June 1991
- Copyright (C) 1989, 1991 Free Software Foundation, Inc.
- 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
+ Copyright (C) 1989, 1991 Free Software Foundation, Inc.,
+ 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
Everyone is permitted to copy and distribute verbatim copies
of this license document, but changing it is not allowed.
- Preamble
+ Preamble
The licenses for most software are designed to take away your
freedom to share and change it. By contrast, the GNU General Public
@@ -15,7 +15,7 @@ software--to make sure the software is free for all its users. This
General Public License applies to most of the Free Software
Foundation's software and to any other program whose authors commit to
using it. (Some other Free Software Foundation software is covered by
-the GNU Library General Public License instead.) You can apply it to
+the GNU Lesser General Public License instead.) You can apply it to
your programs, too.
When we speak of free software, we are referring to freedom, not
@@ -55,8 +55,8 @@ patent must be licensed for everyone's free use or not licensed at all.
The precise terms and conditions for copying, distribution and
modification follow.
-
- GNU GENERAL PUBLIC LICENSE
+
+ GNU GENERAL PUBLIC LICENSE
TERMS AND CONDITIONS FOR COPYING, DISTRIBUTION AND MODIFICATION
0. This License applies to any program or other work which contains
@@ -110,7 +110,7 @@ above, provided that you also meet all of these conditions:
License. (Exception: if the Program itself is interactive but
does not normally print such an announcement, your work based on
the Program is not required to print an announcement.)
-
+
These requirements apply to the modified work as a whole. If
identifiable sections of that work are not derived from the Program,
and can be reasonably considered independent and separate works in
@@ -168,7 +168,7 @@ access to copy from a designated place, then offering equivalent
access to copy the source code from the same place counts as
distribution of the source code, even though third parties are not
compelled to copy the source along with the object code.
-
+
4. You may not copy, modify, sublicense, or distribute the Program
except as expressly provided under this License. Any attempt
otherwise to copy, modify, sublicense or distribute the Program is
@@ -225,7 +225,7 @@ impose that choice.
This section is intended to make thoroughly clear what is believed to
be a consequence of the rest of this License.
-
+
8. If the distribution and/or use of the Program is restricted in
certain countries either by patents or by copyrighted interfaces, the
original copyright holder who places the Program under this License
@@ -255,7 +255,7 @@ make exceptions for this. Our decision will be guided by the two goals
of preserving the free status of all derivatives of our free software and
of promoting the sharing and reuse of software generally.
- NO WARRANTY
+ NO WARRANTY
11. BECAUSE THE PROGRAM IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
FOR THE PROGRAM, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT WHEN
@@ -277,9 +277,9 @@ YOU OR THIRD PARTIES OR A FAILURE OF THE PROGRAM TO OPERATE WITH ANY OTHER
PROGRAMS), EVEN IF SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE
POSSIBILITY OF SUCH DAMAGES.
- END OF TERMS AND CONDITIONS
-
- How to Apply These Terms to Your New Programs
+ END OF TERMS AND CONDITIONS
+
+ How to Apply These Terms to Your New Programs
If you develop a new program, and you want it to be of the greatest
possible use to the public, the best way to achieve this is to make it
@@ -303,10 +303,9 @@ the "copyright" line and a pointer to where the full notice is found.
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.
- You should have received a copy of the GNU General Public License
- along with this program; if not, write to the Free Software
- Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
-
+ You should have received a copy of the GNU General Public License along
+ with this program; if not, write to the Free Software Foundation, Inc.,
+ 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
Also add information on how to contact you by electronic and paper mail.
@@ -336,5 +335,5 @@ necessary. Here is a sample; alter the names:
This General Public License does not permit incorporating your program into
proprietary programs. If your program is a subroutine library, you may
consider it more useful to permit linking proprietary applications with the
-library. If this is what you want to do, use the GNU Library General
+library. If this is what you want to do, use the GNU Lesser General
Public License instead of this License.
diff --git a/choupas/www/admin/phpmy/README b/choupas/www/admin/phpmy/README
index 667a541..1c77549 100644
--- a/choupas/www/admin/phpmy/README
+++ b/choupas/www/admin/phpmy/README
@@ -1,11 +1,11 @@
phpMyAdmin - Readme
===================
-Version 4.4.9
+Version 4.5.4.1
A set of PHP-scripts to manage MySQL over the web.
-http://www.phpmyadmin.net/
+https://www.phpmyadmin.net/
Summary
-------
diff --git a/choupas/www/admin/phpmy/RELEASE-DATE-4.4.9 b/choupas/www/admin/phpmy/RELEASE-DATE-4.4.9
deleted file mode 100644
index 88cbe5a..0000000
--- a/choupas/www/admin/phpmy/RELEASE-DATE-4.4.9
+++ /dev/null
@@ -1 +0,0 @@
-Thu Jun 4 17:20:40 UTC 2015
diff --git a/choupas/www/admin/phpmy/browse_foreigners.php b/choupas/www/admin/phpmy/browse_foreigners.php
index 444d01f..793c00b 100644
--- a/choupas/www/admin/phpmy/browse_foreigners.php
+++ b/choupas/www/admin/phpmy/browse_foreigners.php
@@ -58,4 +58,3 @@ $html = PMA_getHtmlForRelationalFieldSelection(
);
$response->addHtml($html);
-?>
diff --git a/choupas/www/admin/phpmy/changelog.php b/choupas/www/admin/phpmy/changelog.php
index 5066ffe..6dbd495 100644
--- a/choupas/www/admin/phpmy/changelog.php
+++ b/choupas/www/admin/phpmy/changelog.php
@@ -33,7 +33,10 @@ if (is_readable($filename)) {
}
} else {
printf(
- __('The %s file is not available on this system, please visit www.phpmyadmin.net for more information.'),
+ __(
+ 'The %s file is not available on this system, please visit '
+ . 'www.phpmyadmin.net for more information.'
+ ),
$filename
);
exit;
@@ -91,6 +94,10 @@ $replaces = array(
'/(? 'bug #\\1',
+ // GitHub issues
+ '/issue\s*#?([0-9]{4,5}) /i'
+ => 'issue #\\1 ',
+
// transitioned SF.net project bug/rfe/patch links
// by the time we reach 6-digit numbers, we can probably retire the above links
'/patch\s*#?([0-9]{4,5}) /i'
@@ -108,7 +115,7 @@ $replaces = array(
// PMASAentries
'/(PMASA-[0-9]+-[0-9]+)/'
- => '\\1',
+ => '\\1',
// Highlight releases (with links)
'/([0-9]+)\.([0-9]+)\.([0-9]+)\.0 (\([0-9-]+\))/'
diff --git a/choupas/www/admin/phpmy/composer.json b/choupas/www/admin/phpmy/composer.json
index 117a2c8..1eba353 100644
--- a/choupas/www/admin/phpmy/composer.json
+++ b/choupas/www/admin/phpmy/composer.json
@@ -3,27 +3,34 @@
"type": "application",
"description": "MySQL web administration tool",
"keywords": ["phpmyadmin","mysql","web"],
- "homepage": "http://www.phpmyadmin.net/",
+ "homepage": "https://www.phpmyadmin.net/",
"license": "GPL-2.0+",
"authors": [
{
"name": "The phpMyAdmin Team",
- "email": "phpmyadmin-devel@lists.sourceforge.net",
- "homepage": "http://www.phpmyadmin.net/home_page/team.php"
+ "email": "developers@phpmyadmin.net",
+ "homepage": "https://www.phpmyadmin.net/team/"
}
],
"support": {
- "forum": "https://sourceforge.net/p/phpmyadmin/discussion/Help",
- "issues": "https://sourceforge.net/p/phpmyadmin/bugs/",
+ "forum": "https://www.phpmyadmin.net/support/",
+ "issues": "https://github.com/phpmyadmin/phpmyadmin/issues",
"wiki": "http://wiki.phpmyadmin.net/",
"source": "https://github.com/phpmyadmin/phpmyadmin"
},
"require": {
- "php": ">=5.3.0"
+ "php": ">=5.5.0"
},
"require-dev": {
"satooshi/php-coveralls": ">=0.6",
- "phpunit/phpunit": "<4.2",
- "phpunit/phpunit-selenium": ">=1.2"
- }
+ "phpunit/phpunit": ">=3.7",
+ "phpunit/phpunit-selenium": ">=1.2",
+ "squizlabs/php_codesniffer": "2.*"
+ },
+ "repositories": [
+ {
+ "type": "composer",
+ "url": "https://www.phpmyadmin.net"
+ }
+ ]
}
diff --git a/choupas/www/admin/phpmy/config.inc.php b/choupas/www/admin/phpmy/config.inc.php
deleted file mode 100644
index d805628..0000000
--- a/choupas/www/admin/phpmy/config.inc.php
+++ /dev/null
@@ -1,152 +0,0 @@
-.
- *
- * @package PhpMyAdmin
- */
-
-/*
- * This is needed for cookie based authentication to encrypt password in
- * cookie
- */
-$cfg['blowfish_secret'] = ''; /* YOU MUST FILL IN THIS FOR COOKIE AUTH! */
-
-/*
- * Servers configuration
- */
-$i = 0;
-
-/*
- * First server
- */
-$i++;
-/* Authentication type */
-$cfg['Servers'][$i]['auth_type'] = 'cookie';
-/* Server parameters */
-$cfg['Servers'][$i]['host'] = '10.42.42.8';
-$cfg['Servers'][$i]['connect_type'] = 'tcp';
-$cfg['Servers'][$i]['compress'] = false;
-$cfg['Servers'][$i]['AllowNoPassword'] = false;
-
-/*
- * phpMyAdmin configuration storage settings.
- */
-
-/* User used to manipulate with storage */
-// $cfg['Servers'][$i]['controlhost'] = '';
-// $cfg['Servers'][$i]['controlport'] = '';
-// $cfg['Servers'][$i]['controluser'] = 'pma';
-// $cfg['Servers'][$i]['controlpass'] = 'pmapass';
-
-/* Storage database and tables */
-// $cfg['Servers'][$i]['pmadb'] = 'phpmyadmin';
-// $cfg['Servers'][$i]['bookmarktable'] = 'pma__bookmark';
-// $cfg['Servers'][$i]['relation'] = 'pma__relation';
-// $cfg['Servers'][$i]['table_info'] = 'pma__table_info';
-// $cfg['Servers'][$i]['table_coords'] = 'pma__table_coords';
-// $cfg['Servers'][$i]['pdf_pages'] = 'pma__pdf_pages';
-// $cfg['Servers'][$i]['column_info'] = 'pma__column_info';
-// $cfg['Servers'][$i]['history'] = 'pma__history';
-// $cfg['Servers'][$i]['table_uiprefs'] = 'pma__table_uiprefs';
-// $cfg['Servers'][$i]['tracking'] = 'pma__tracking';
-// $cfg['Servers'][$i]['userconfig'] = 'pma__userconfig';
-// $cfg['Servers'][$i]['recent'] = 'pma__recent';
-// $cfg['Servers'][$i]['favorite'] = 'pma__favorite';
-// $cfg['Servers'][$i]['users'] = 'pma__users';
-// $cfg['Servers'][$i]['usergroups'] = 'pma__usergroups';
-// $cfg['Servers'][$i]['navigationhiding'] = 'pma__navigationhiding';
-// $cfg['Servers'][$i]['savedsearches'] = 'pma__savedsearches';
-// $cfg['Servers'][$i]['central_columns'] = 'pma__central_columns';
-/* Contrib / Swekey authentication */
-// $cfg['Servers'][$i]['auth_swekey_config'] = '/etc/swekey-pma.conf';
-
-/*
- * End of servers configuration
- */
-
-/*
- * Directories for saving/loading files from server
- */
-$cfg['UploadDir'] = '';
-$cfg['SaveDir'] = '';
-
-/**
- * Whether to display icons or text or both icons and text in table row
- * action segment. Value can be either of 'icons', 'text' or 'both'.
- */
-//$cfg['RowActionType'] = 'both';
-
-/**
- * Defines whether a user should be displayed a "show all (records)"
- * button in browse mode or not.
- * default = false
- */
-//$cfg['ShowAll'] = true;
-
-/**
- * Number of rows displayed when browsing a result set. If the result
- * set contains more rows, "Previous" and "Next".
- * default = 30
- */
-//$cfg['MaxRows'] = 50;
-
-/**
- * disallow editing of binary fields
- * valid values are:
- * false allow editing
- * 'blob' allow editing except for BLOB fields
- * 'noblob' disallow editing except for BLOB fields
- * 'all' disallow editing
- * default = blob
- */
-//$cfg['ProtectBinary'] = 'false';
-
-/**
- * Default language to use, if not browser-defined or user-defined
- * (you find all languages in the locale folder)
- * uncomment the desired line:
- * default = 'en'
- */
-//$cfg['DefaultLang'] = 'en';
-//$cfg['DefaultLang'] = 'de';
-
-/**
- * How many columns should be used for table display of a database?
- * (a value larger than 1 results in some information being hidden)
- * default = 1
- */
-//$cfg['PropertiesNumColumns'] = 2;
-
-/**
- * Set to true if you want DB-based query history.If false, this utilizes
- * JS-routines to display query history (lost by window close)
- *
- * This requires configuration storage enabled, see above.
- * default = false
- */
-//$cfg['QueryHistoryDB'] = true;
-
-/**
- * When using DB-based query history, how many entries should be kept?
- *
- * default = 25
- */
-//$cfg['QueryHistoryMax'] = 100;
-
-/**
- * Should error reporting be enabled for JavaScript errors
- *
- * default = 'ask'
- */
-//$cfg['SendErrorReports'] = 'ask';
-
-/*
- * You can find more configuration options in the documentation
- * in the doc/ folder or at .
- */
-?>
diff --git a/choupas/www/admin/phpmy/config.sample.inc.php b/choupas/www/admin/phpmy/config.sample.inc.php
index 035ebb8..5c73c2e 100644
--- a/choupas/www/admin/phpmy/config.sample.inc.php
+++ b/choupas/www/admin/phpmy/config.sample.inc.php
@@ -10,18 +10,18 @@
* @package PhpMyAdmin
*/
-/*
+/**
* This is needed for cookie based authentication to encrypt password in
* cookie
*/
$cfg['blowfish_secret'] = ''; /* YOU MUST FILL IN THIS FOR COOKIE AUTH! */
-/*
+/**
* Servers configuration
*/
$i = 0;
-/*
+/**
* First server
*/
$i++;
@@ -33,7 +33,7 @@ $cfg['Servers'][$i]['connect_type'] = 'tcp';
$cfg['Servers'][$i]['compress'] = false;
$cfg['Servers'][$i]['AllowNoPassword'] = false;
-/*
+/**
* phpMyAdmin configuration storage settings.
*/
@@ -62,14 +62,16 @@ $cfg['Servers'][$i]['AllowNoPassword'] = false;
// $cfg['Servers'][$i]['navigationhiding'] = 'pma__navigationhiding';
// $cfg['Servers'][$i]['savedsearches'] = 'pma__savedsearches';
// $cfg['Servers'][$i]['central_columns'] = 'pma__central_columns';
+// $cfg['Servers'][$i]['designer_settings'] = 'pma__designer_settings';
+// $cfg['Servers'][$i]['export_templates'] = 'pma__export_templates';
/* Contrib / Swekey authentication */
// $cfg['Servers'][$i]['auth_swekey_config'] = '/etc/swekey-pma.conf';
-/*
+/**
* End of servers configuration
*/
-/*
+/**
* Directories for saving/loading files from server
*/
$cfg['UploadDir'] = '';
@@ -78,8 +80,9 @@ $cfg['SaveDir'] = '';
/**
* Whether to display icons or text or both icons and text in table row
* action segment. Value can be either of 'icons', 'text' or 'both'.
+ * default = 'both'
*/
-//$cfg['RowActionType'] = 'both';
+//$cfg['RowActionType'] = 'icons';
/**
* Defines whether a user should be displayed a "show all (records)"
@@ -91,20 +94,21 @@ $cfg['SaveDir'] = '';
/**
* Number of rows displayed when browsing a result set. If the result
* set contains more rows, "Previous" and "Next".
- * default = 30
+ * Possible values: 25, 50, 100, 250, 500
+ * default = 25
*/
//$cfg['MaxRows'] = 50;
/**
- * disallow editing of binary fields
+ * Disallow editing of binary fields
* valid values are:
* false allow editing
* 'blob' allow editing except for BLOB fields
* 'noblob' disallow editing except for BLOB fields
* 'all' disallow editing
- * default = blob
+ * default = 'blob'
*/
-//$cfg['ProtectBinary'] = 'false';
+//$cfg['ProtectBinary'] = false;
/**
* Default language to use, if not browser-defined or user-defined
@@ -133,20 +137,21 @@ $cfg['SaveDir'] = '';
/**
* When using DB-based query history, how many entries should be kept?
- *
* default = 25
*/
//$cfg['QueryHistoryMax'] = 100;
/**
- * Should error reporting be enabled for JavaScript errors
+ * Whether or not to query the user before sending the error report to
+ * the phpMyAdmin team when a JavaScript error occurs
*
+ * Available options
+ * ('ask' | 'always' | 'never')
* default = 'ask'
*/
-//$cfg['SendErrorReports'] = 'ask';
+//$cfg['SendErrorReports'] = 'always';
-/*
+/**
* You can find more configuration options in the documentation
* in the doc/ folder or at .
*/
-?>
diff --git a/choupas/www/admin/phpmy/db_central_columns.php b/choupas/www/admin/phpmy/db_central_columns.php
index 997cffc..2e9aac7 100644
--- a/choupas/www/admin/phpmy/db_central_columns.php
+++ b/choupas/www/admin/phpmy/db_central_columns.php
@@ -10,7 +10,6 @@
* Gets some core libraries
*/
require_once 'libraries/common.inc.php';
-require_once 'libraries/tbl_columns_definition_form.lib.php';
require_once 'libraries/central_columns.lib.php';
if (isset($_POST['edit_save']) || isset($_POST['add_new_column'])) {
@@ -22,7 +21,7 @@ if (isset($_POST['edit_save']) || isset($_POST['add_new_column'])) {
if ($col_default == 'NONE' && $_POST['col_default_sel'] != 'USER_DEFINED') {
$col_default = "";
}
- $col_extra = $_POST['col_extra'];
+ $col_extra = isset($_POST['col_extra']) ? $_POST['col_extra'] : '';
$col_isNull = isset($_POST['col_isNull'])?1:0;
$col_length = $_POST['col_length'];
$col_attribute = $_POST['col_attribute'];
@@ -30,13 +29,13 @@ if (isset($_POST['edit_save']) || isset($_POST['add_new_column'])) {
$collation = $_POST['collation'];
if (isset($orig_col_name) && $orig_col_name) {
echo PMA_updateOneColumn(
- $db, $orig_col_name, $col_name, $col_type,$col_attribute,
+ $db, $orig_col_name, $col_name, $col_type, $col_attribute,
$col_length, $col_isNull, $collation, $col_extra, $col_default
);
exit;
} else {
$tmp_msg = PMA_updateOneColumn(
- $db, "", $col_name, $col_type,$col_attribute,
+ $db, "", $col_name, $col_type, $col_attribute,
$col_length, $col_isNull, $collation, $col_extra, $col_default
);
}
@@ -66,10 +65,27 @@ $cfgCentralColumns = PMA_centralColumnsGetParams();
$pmadb = $cfgCentralColumns['db'];
$pmatable = $cfgCentralColumns['table'];
$max_rows = $GLOBALS['cfg']['MaxRows'];
+
+if (isset($_REQUEST['edit_central_columns_page'])) {
+ $selected_fld = $_REQUEST['selected_fld'];
+ $selected_db = $_REQUEST['db'];
+ $edit_central_column_page = PMA_getHTMLforEditingPage(
+ $selected_fld, $selected_db
+ );
+ $response->addHTML($edit_central_column_page);
+ exit;
+}
+if (isset($_POST['multi_edit_central_column_save'])) {
+ $message = PMA_updateMultipleColumn();
+ if (!is_bool($message)) {
+ $response->isSuccess(false);
+ $response->addJSON('message', $message);
+ }
+}
if (isset($_POST['delete_save'])) {
$col_name = array();
- $col_name[] = $_REQUEST['col_name'];
- $tmp_msg = PMA_deleteColumnsFromList($col_name, false);
+ parse_str($_POST['col_name'], $col_name);
+ $tmp_msg = PMA_deleteColumnsFromList($col_name['selected_fld'], false);
}
if (isset($_REQUEST['total_rows']) && $_REQUEST['total_rows']) {
$total_rows = $_REQUEST['total_rows'];
@@ -106,6 +122,7 @@ $deleteRowForm = '';
$response->addHTML($deleteRowForm);
$table_struct = '');
+$response->addHTML('
diff --git a/choupas/www/admin/phpmy/chk_rel.php b/choupas/www/admin/phpmy/chk_rel.php
index 3a55d73..e622884 100644
--- a/choupas/www/admin/phpmy/chk_rel.php
+++ b/choupas/www/admin/phpmy/chk_rel.php
@@ -8,8 +8,15 @@
require_once 'libraries/common.inc.php';
// If request for creating all PMA tables.
if (isset($_REQUEST['create_pmadb'])) {
+ if (PMA_createPMADatabase()) {
+ PMA_fixPMATables('phpmyadmin');
+ }
+}
+
+// If request for creating all PMA tables.
+if (isset($_REQUEST['fixall_pmadb'])) {
PMA_fixPMATables($GLOBALS['db']);
}
@@ -23,5 +30,3 @@ $response = PMA_Response::getInstance();
$response->addHTML(
PMA_getRelationsParamDiagnostic($cfgRelation)
);
-
-?>
@@ -8,8 +8,15 @@
require_once 'libraries/common.inc.php';
-// If request for creating all PMA tables.
+// If request for creating the pmadb
if (isset($_REQUEST['create_pmadb'])) {